# Autotasker
>[!WARNING]
>  This project is still a work in progress, so you may encounter errors while using it.

[![autotasker](https://img.shields.io/badge/documentation-autotasker-blue.svg)](https://autotasker.es)
[![GPL License](https://img.shields.io/badge/license-GPL-blue.svg)](http://www.gnu.org/licenses/gpl-3.0) 
![Version](https://img.shields.io/badge/version-0.2.1-green.svg)
[![Download Stats](https://img.shields.io/pypi/dm/autotasker)](https://pypistats.org/packages/autotasker)
[![Github repository](https://img.shields.io/badge/GitHub-autotasker-purple)](https://github.com/mramosg7/autotasker)


## Application Overview

AutoTasker is a console application designed to simplify and automate repetitive tasks without the need for programming skills. With AutoTasker, you can easily set up a variety of automated tasks, saving you time and effort in your daily activities.

## Installation 
To install AutoTasker, please refer to the detailed installation guide available in the [documentation page](https://autotasker.es/documentation/installation).
## Documentation
Comprehensive documentation for AutoTasker, including setup instructions, feature overviews, and usage examples, is available at the [documentation page](https://autotasker.es).